#!/bin/sh


ACTION=${1}
shift 1

ARCH="default"
IMAGE_NAME='default'

get_image() {
  IMAGE_NAME="jellyfin/jellyfin"
}

do_install() {
  get_image
  echo "docker pull ${IMAGE_NAME}"
  docker pull ${IMAGE_NAME}
  docker rm -f jellyfin

  do_install_detail
}

do_install_detail() {
  local hostnet=`uci get jellyfin.@jellyfin[0].hostnet 2>/dev/null`
  local media=`uci get jellyfin.@jellyfin[0].media_path 2>/dev/null`
  local config=`uci get jellyfin.@jellyfin[0].config_path 2>/dev/null`
  local cache=`uci get jellyfin.@jellyfin[0].cache_path 2>/dev/null`
  local port=`uci get jellyfin.@jellyfin[0].port 2>/dev/null`
  local dev

  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=8096

  local cmd="docker run --restart=unless-stopped -d -v \"$config:/config\" "

  if [ "$hostnet" = 1 ]; then
    cmd="$cmd\
    --dns=127.0.0.1 \
    --network=host "
  else
    cmd="$cmd\
    --dns=172.17.0.1 \
    -p $port:8096 "
  fi

  local tz="`uci get system.@system[0].zonename`"
  [ -z "$tz" ] || cmd="$cmd -e TZ=$tz"

  [ -z "$cache" ] || cmd="$cmd -v \"$cache:/config/transcodes\""
  [ -z "$media" ] || cmd="$cmd -v \"$media:/media\""

  cmd="$cmd -v /mnt:/mnt"
  mountpoint -q /mnt && cmd="$cmd:rslave"
  cmd="$cmd --name jellyfin \"$IMAGE_NAME\""

  echo "$cmd"
  eval "$cmd"

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install the jellyfin"
  echo "      upgrade                Upgrade the jellyfin"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart the jellyfin"
  echo "      status                 Jellyfin status"
  echo "      port                   Jellyfin port"
}

case ${ACTION} in
  "install")
    do_install
  ;;
  "upgrade")
    do_install
  ;;
  "rm")
    docker rm -f jellyfin
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} jellyfin
  ;;
  "status")
    docker ps --all -f 'name=jellyfin' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=jellyfin' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
